
// REQUIRES the following Arduino libraries:
// - DHT Sensor Library: https://github.com/adafruit/DHT-sensor-library
// - Adafruit Unified Sensor Lib: https://github.com/adafruit/Adafruit_Sensor
//  This code is based on the DHT library example code but tweaked to work with 2 sensors in parallel.

#include "DHT.h"

#define DHT22PIN 5     // Digital pin connected to the DHT22 sensor
#define DHT11PIN 6     // Digital pin connected to the DHT11 sensor

#define DHTTYPE11 DHT11   // DHT 11
#define DHTTYPE22 DHT22   // DHT 22  (AM2302), AM2321
//#define DHTTYPE DHT21   // DHT 21 (AM2301)


// Initialize DHT sensor.
DHT dht11(DHT11PIN, DHTTYPE11);
DHT dht22(DHT22PIN, DHTTYPE22);

unsigned long startTime, loopTime, difTime;

void setup() {
  Serial.begin(9600);
  Serial.println("DHT11 & DHT22 test!");

  dht11.begin();
  dht22.begin();
  
}

void loop() {
  // Wait a few seconds between measurements.
  startTime = millis();
  delay(250);

  // Reading temperature or humidity takes about 250 milliseconds!
  // Sensor readings may also be up to 2 seconds 'old' (its a very slow sensor)
  float h11 = dht11.readHumidity();
  // Read temperature as Celsius (the default)
  float t11 = dht11.readTemperature();
  // Read temperature as Fahrenheit (isFahrenheit = true)
  float f11 = dht11.readTemperature(true);

  float h22 = dht22.readHumidity();
  // Read temperature as Celsius (the default)
  float t22 = dht22.readTemperature();
  // Read temperature as Fahrenheit (isFahrenheit = true)
  float f22 = dht22.readTemperature(true);

  // Reading temperature or humidity takes about 250 milliseconds!
  //Calculate apparent air temperature
  float hic11 = dht11.computeHeatIndex(t11, h11, false);
  float hic22 = dht22.computeHeatIndex(t22, h22, false);

  // Check if any reads failed and exit early (to try again).
  if (isnan(h11) || isnan(t11) || isnan(f11)) {
    Serial.println(F("Failed to read from DHT11 sensor!"));
    return;
  }
  if (isnan(h22) || isnan(t22) || isnan(f22)) {
    Serial.println("Failed to read from DHT22 sensor!");
    return;
  }
  
  loopTime = millis();
  difTime = loopTime - startTime;
  
  Serial.print("DHT11: Humidity: ");
  Serial.print(h11);
  Serial.print("%, ");
  
  Serial.print("Temperature: ");
  Serial.print(t11);
  Serial.print("°C, ");

  Serial.print("Apparent Temperature: ");
  Serial.print(hic11);
  Serial.println("°C, ");
    

  Serial.print("DHT22: Humidity: ");
  Serial.print(h22);
  Serial.print("%, ");
  
  Serial.print("Temperature: ");
  Serial.print(t22);
  Serial.print("°C, ");

  Serial.print("Apparent Temperature: ");
  Serial.print(hic22);
  Serial.println("°C, ");

  Serial.print("Loop time ");
  Serial.print(difTime);
  Serial.println("ms");
  Serial.println("");

  
  


}
